@@ -12,6 +12,7 @@ use HTML::TreeBuilder;
 has app => qw/is ro isa App::PM::Announce required 1/, handles => [qw/ logger /];
 has username => qw/is ro isa Str required 1/;
 has password => qw/is ro isa Str required 1/;
+has uri => qw/is ro required 1/;
 
 has agent => qw/is ro lazy_build 1/, handles => [qw/ submit_form /];
 sub _build_agent {
@@ -20,14 +21,14 @@ sub _build_agent {
 
 sub get {
     my $self = shift;
-    $self->logger->debug( "get $_[0]" );
+    $self->logger->debug( "GET $_[0]" );
     $self->agent->request( GET @_ );
 #    $self->agent->get( @_ );
 }
 
 sub post {
     my $self = shift;
-    $self->logger->debug( "post $_[0]" );
+    $self->logger->debug( "POST $_[0]" );
 #    $self->agent->post( @_ );
     $self->agent->request( POST @_ );
 }
